#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 foldl
version:              1.4.18
visibility:           public
id:                   foldl-1.4.18-33Qp6Knmh9K5Nj5bK1spOS
key:                  foldl-1.4.18-33Qp6Knmh9K5Nj5bK1spOS
license:              BSD-3-Clause
copyright:            2013 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.

category:             Control
abi:                  98a5be9c7bb3eb1af2b8ce8043c74f5c
exposed:              True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.NonEmpty
    Control.Foldl.Text Control.Scanl

hidden-modules:
    Control.Foldl.Optics Control.Foldl.Internal
    Control.Foldl.Util.Vector Control.Foldl.Util.MVector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
library-dirs:         /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/foldl-1.4.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-foldl
hs-libraries:         HSfoldl-1.4.18-33Qp6Knmh9K5Nj5bK1spOS
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    comonad-5.0.9-1xMovbKbUwG9UbUoSlXsA5 containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    hashable-1.4.7.0-IX17aYqP3drGri7tV4VHWj
    primitive-0.9.1.0-DNYUiteSkWM3A4YLtDD08v
    profunctors-5.6.3-73PycQx5aLvK69VcQuinqd
    random-1.2.1.3-61dnBQTdVAfCNopGABDCH1
    semigroupoids-6.0.2-Grt7Ni2XiTMG7sltNin4w6 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50KuqheKibtHrVzrLcPiuM
    vector-0.13.2.0-5YxFBFTVtOB5p4D1EBw8Kb

haddock-interfaces:   /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html:         /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

